@@ -17,8 +17,10 @@
 #include <aws/ecs/ECS_EXPORTS.h>
 #include <aws/ecs/ECSRequest.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/ecs/model/DeploymentConfiguration.h>
 #include <aws/ecs/model/NetworkConfiguration.h>
+#include <aws/ecs/model/CapacityProviderStrategyItem.h>
 #include <utility>
 
 namespace Aws
@@ -250,6 +252,79 @@ namespace Model
     inline UpdateServiceRequest& WithTaskDefinition(const char* value) { SetTaskDefinition(value); return *this;}
 
 
+    /**
+     * <p>The capacity provider strategy to update the service to use.</p> <p>If the
+     * service is using the default capacity provider strategy for the cluster, the
+     * service can be updated to use one or more capacity providers. However, when a
+     * service is using a non-default capacity provider strategy, the service cannot be
+     * updated to use the cluster's default capacity provider strategy.</p> <p/>
+     */
+    inline const Aws::Vector<CapacityProviderStrategyItem>& GetCapacityProviderStrategy() const{ return m_capacityProviderStrategy; }
+
+    /**
+     * <p>The capacity provider strategy to update the service to use.</p> <p>If the
+     * service is using the default capacity provider strategy for the cluster, the
+     * service can be updated to use one or more capacity providers. However, when a
+     * service is using a non-default capacity provider strategy, the service cannot be
+     * updated to use the cluster's default capacity provider strategy.</p> <p/>
+     */
+    inline bool CapacityProviderStrategyHasBeenSet() const { return m_capacityProviderStrategyHasBeenSet; }
+
+    /**
+     * <p>The capacity provider strategy to update the service to use.</p> <p>If the
+     * service is using the default capacity provider strategy for the cluster, the
+     * service can be updated to use one or more capacity providers. However, when a
+     * service is using a non-default capacity provider strategy, the service cannot be
+     * updated to use the cluster's default capacity provider strategy.</p> <p/>
+     */
+    inline void SetCapacityProviderStrategy(const Aws::Vector<CapacityProviderStrategyItem>& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy = value; }
+
+    /**
+     * <p>The capacity provider strategy to update the service to use.</p> <p>If the
+     * service is using the default capacity provider strategy for the cluster, the
+     * service can be updated to use one or more capacity providers. However, when a
+     * service is using a non-default capacity provider strategy, the service cannot be
+     * updated to use the cluster's default capacity provider strategy.</p> <p/>
+     */
+    inline void SetCapacityProviderStrategy(Aws::Vector<CapacityProviderStrategyItem>&& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy = std::move(value); }
+
+    /**
+     * <p>The capacity provider strategy to update the service to use.</p> <p>If the
+     * service is using the default capacity provider strategy for the cluster, the
+     * service can be updated to use one or more capacity providers. However, when a
+     * service is using a non-default capacity provider strategy, the service cannot be
+     * updated to use the cluster's default capacity provider strategy.</p> <p/>
+     */
+    inline UpdateServiceRequest& WithCapacityProviderStrategy(const Aws::Vector<CapacityProviderStrategyItem>& value) { SetCapacityProviderStrategy(value); return *this;}
+
+    /**
+     * <p>The capacity provider strategy to update the service to use.</p> <p>If the
+     * service is using the default capacity provider strategy for the cluster, the
+     * service can be updated to use one or more capacity providers. However, when a
+     * service is using a non-default capacity provider strategy, the service cannot be
+     * updated to use the cluster's default capacity provider strategy.</p> <p/>
+     */
+    inline UpdateServiceRequest& WithCapacityProviderStrategy(Aws::Vector<CapacityProviderStrategyItem>&& value) { SetCapacityProviderStrategy(std::move(value)); return *this;}
+
+    /**
+     * <p>The capacity provider strategy to update the service to use.</p> <p>If the
+     * service is using the default capacity provider strategy for the cluster, the
+     * service can be updated to use one or more capacity providers. However, when a
+     * service is using a non-default capacity provider strategy, the service cannot be
+     * updated to use the cluster's default capacity provider strategy.</p> <p/>
+     */
+    inline UpdateServiceRequest& AddCapacityProviderStrategy(const CapacityProviderStrategyItem& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy.push_back(value); return *this; }
+
+    /**
+     * <p>The capacity provider strategy to update the service to use.</p> <p>If the
+     * service is using the default capacity provider strategy for the cluster, the
+     * service can be updated to use one or more capacity providers. However, when a
+     * service is using a non-default capacity provider strategy, the service cannot be
+     * updated to use the cluster's default capacity provider strategy.</p> <p/>
+     */
+    inline UpdateServiceRequest& AddCapacityProviderStrategy(CapacityProviderStrategyItem&& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy.push_back(std::move(value)); return *this; }
+
+
     /**
      * <p>Optional deployment parameters that control how many tasks run during the
      * deployment and the ordering of stopping and starting tasks.</p>
@@ -287,102 +362,30 @@ namespace Model
     inline UpdateServiceRequest& WithDeploymentConfiguration(DeploymentConfiguration&& value) { SetDeploymentConfiguration(std::move(value)); return *this;}
 
 
-    /**
-     * <p>The network configuration for the service. This parameter is required for
-     * task definitions that use the <code>awsvpc</code> network mode to receive their
-     * own elastic network interface, and it is not supported for other network modes.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html">Task
-     * Networking</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <note> <p>Updating a service to add a subnet to a list of
-     * existing subnets does not trigger a service deployment. For example, if your
-     * network configuration change is to keep the existing subnets and simply add
-     * another subnet to the network configuration, this does not trigger a new service
-     * deployment.</p> </note>
-     */
+    
     inline const NetworkConfiguration& GetNetworkConfiguration() const{ return m_networkConfiguration; }
 
-    /**
-     * <p>The network configuration for the service. This parameter is required for
-     * task definitions that use the <code>awsvpc</code> network mode to receive their
-     * own elastic network interface, and it is not supported for other network modes.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html">Task
-     * Networking</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <note> <p>Updating a service to add a subnet to a list of
-     * existing subnets does not trigger a service deployment. For example, if your
-     * network configuration change is to keep the existing subnets and simply add
-     * another subnet to the network configuration, this does not trigger a new service
-     * deployment.</p> </note>
-     */
+    
     inline bool NetworkConfigurationHasBeenSet() const { return m_networkConfigurationHasBeenSet; }
 
-    /**
-     * <p>The network configuration for the service. This parameter is required for
-     * task definitions that use the <code>awsvpc</code> network mode to receive their
-     * own elastic network interface, and it is not supported for other network modes.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html">Task
-     * Networking</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <note> <p>Updating a service to add a subnet to a list of
-     * existing subnets does not trigger a service deployment. For example, if your
-     * network configuration change is to keep the existing subnets and simply add
-     * another subnet to the network configuration, this does not trigger a new service
-     * deployment.</p> </note>
-     */
+    
     inline void SetNetworkConfiguration(const NetworkConfiguration& value) { m_networkConfigurationHasBeenSet = true; m_networkConfiguration = value; }
 
-    /**
-     * <p>The network configuration for the service. This parameter is required for
-     * task definitions that use the <code>awsvpc</code> network mode to receive their
-     * own elastic network interface, and it is not supported for other network modes.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html">Task
-     * Networking</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <note> <p>Updating a service to add a subnet to a list of
-     * existing subnets does not trigger a service deployment. For example, if your
-     * network configuration change is to keep the existing subnets and simply add
-     * another subnet to the network configuration, this does not trigger a new service
-     * deployment.</p> </note>
-     */
+    
     inline void SetNetworkConfiguration(NetworkConfiguration&& value) { m_networkConfigurationHasBeenSet = true; m_networkConfiguration = std::move(value); }
 
-    /**
-     * <p>The network configuration for the service. This parameter is required for
-     * task definitions that use the <code>awsvpc</code> network mode to receive their
-     * own elastic network interface, and it is not supported for other network modes.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html">Task
-     * Networking</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <note> <p>Updating a service to add a subnet to a list of
-     * existing subnets does not trigger a service deployment. For example, if your
-     * network configuration change is to keep the existing subnets and simply add
-     * another subnet to the network configuration, this does not trigger a new service
-     * deployment.</p> </note>
-     */
+    
     inline UpdateServiceRequest& WithNetworkConfiguration(const NetworkConfiguration& value) { SetNetworkConfiguration(value); return *this;}
 
-    /**
-     * <p>The network configuration for the service. This parameter is required for
-     * task definitions that use the <code>awsvpc</code> network mode to receive their
-     * own elastic network interface, and it is not supported for other network modes.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html">Task
-     * Networking</a> in the <i>Amazon Elastic Container Service Developer
-     * Guide</i>.</p> <note> <p>Updating a service to add a subnet to a list of
-     * existing subnets does not trigger a service deployment. For example, if your
-     * network configuration change is to keep the existing subnets and simply add
-     * another subnet to the network configuration, this does not trigger a new service
-     * deployment.</p> </note>
-     */
+    
     inline UpdateServiceRequest& WithNetworkConfiguration(NetworkConfiguration&& value) { SetNetworkConfiguration(std::move(value)); return *this;}
 
 
     /**
      * <p>The platform version on which your tasks in the service are running. A
-     * platform version is only specified for tasks using the Fargate launch type. If
-     * one is not specified, the <code>LATEST</code> platform version is used by
-     * default. For more information, see <a
+     * platform version is only specified for tasks using the Fargate launch type. If a
+     * platform version is not specified, the <code>LATEST</code> platform version is
+     * used by default. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html">AWS
      * Fargate Platform Versions</a> in the <i>Amazon Elastic Container Service
      * Developer Guide</i>.</p>
@@ -391,9 +394,9 @@ namespace Model
 
     /**
      * <p>The platform version on which your tasks in the service are running. A
-     * platform version is only specified for tasks using the Fargate launch type. If
-     * one is not specified, the <code>LATEST</code> platform version is used by
-     * default. For more information, see <a
+     * platform version is only specified for tasks using the Fargate launch type. If a
+     * platform version is not specified, the <code>LATEST</code> platform version is
+     * used by default. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html">AWS
      * Fargate Platform Versions</a> in the <i>Amazon Elastic Container Service
      * Developer Guide</i>.</p>
@@ -402,9 +405,9 @@ namespace Model
 
     /**
      * <p>The platform version on which your tasks in the service are running. A
-     * platform version is only specified for tasks using the Fargate launch type. If
-     * one is not specified, the <code>LATEST</code> platform version is used by
-     * default. For more information, see <a
+     * platform version is only specified for tasks using the Fargate launch type. If a
+     * platform version is not specified, the <code>LATEST</code> platform version is
+     * used by default. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html">AWS
      * Fargate Platform Versions</a> in the <i>Amazon Elastic Container Service
      * Developer Guide</i>.</p>
@@ -413,9 +416,9 @@ namespace Model
 
     /**
      * <p>The platform version on which your tasks in the service are running. A
-     * platform version is only specified for tasks using the Fargate launch type. If
-     * one is not specified, the <code>LATEST</code> platform version is used by
-     * default. For more information, see <a
+     * platform version is only specified for tasks using the Fargate launch type. If a
+     * platform version is not specified, the <code>LATEST</code> platform version is
+     * used by default. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html">AWS
      * Fargate Platform Versions</a> in the <i>Amazon Elastic Container Service
      * Developer Guide</i>.</p>
@@ -424,9 +427,9 @@ namespace Model
 
     /**
      * <p>The platform version on which your tasks in the service are running. A
-     * platform version is only specified for tasks using the Fargate launch type. If
-     * one is not specified, the <code>LATEST</code> platform version is used by
-     * default. For more information, see <a
+     * platform version is only specified for tasks using the Fargate launch type. If a
+     * platform version is not specified, the <code>LATEST</code> platform version is
+     * used by default. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html">AWS
      * Fargate Platform Versions</a> in the <i>Amazon Elastic Container Service
      * Developer Guide</i>.</p>
@@ -435,9 +438,9 @@ namespace Model
 
     /**
      * <p>The platform version on which your tasks in the service are running. A
-     * platform version is only specified for tasks using the Fargate launch type. If
-     * one is not specified, the <code>LATEST</code> platform version is used by
-     * default. For more information, see <a
+     * platform version is only specified for tasks using the Fargate launch type. If a
+     * platform version is not specified, the <code>LATEST</code> platform version is
+     * used by default. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html">AWS
      * Fargate Platform Versions</a> in the <i>Amazon Elastic Container Service
      * Developer Guide</i>.</p>
@@ -446,9 +449,9 @@ namespace Model
 
     /**
      * <p>The platform version on which your tasks in the service are running. A
-     * platform version is only specified for tasks using the Fargate launch type. If
-     * one is not specified, the <code>LATEST</code> platform version is used by
-     * default. For more information, see <a
+     * platform version is only specified for tasks using the Fargate launch type. If a
+     * platform version is not specified, the <code>LATEST</code> platform version is
+     * used by default. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html">AWS
      * Fargate Platform Versions</a> in the <i>Amazon Elastic Container Service
      * Developer Guide</i>.</p>
@@ -457,9 +460,9 @@ namespace Model
 
     /**
      * <p>The platform version on which your tasks in the service are running. A
-     * platform version is only specified for tasks using the Fargate launch type. If
-     * one is not specified, the <code>LATEST</code> platform version is used by
-     * default. For more information, see <a
+     * platform version is only specified for tasks using the Fargate launch type. If a
+     * platform version is not specified, the <code>LATEST</code> platform version is
+     * used by default. For more information, see <a
      * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html">AWS
      * Fargate Platform Versions</a> in the <i>Amazon Elastic Container Service
      * Developer Guide</i>.</p>
@@ -510,10 +513,10 @@ namespace Model
      * first started. This is only valid if your service is configured to use a load
      * balancer. If your service's tasks take a while to start and respond to Elastic
      * Load Balancing health checks, you can specify a health check grace period of up
-     * to 2,147,483,647 seconds. During that time, the ECS service scheduler ignores
-     * the Elastic Load Balancing health check status. This grace period can prevent
-     * the ECS service scheduler from marking tasks as unhealthy and stopping them
-     * before they have time to come up.</p>
+     * to 2,147,483,647 seconds. During that time, the Amazon ECS service scheduler
+     * ignores the Elastic Load Balancing health check status. This grace period can
+     * prevent the ECS service scheduler from marking tasks as unhealthy and stopping
+     * them before they have time to come up.</p>
      */
     inline int GetHealthCheckGracePeriodSeconds() const{ return m_healthCheckGracePeriodSeconds; }
 
@@ -523,10 +526,10 @@ namespace Model
      * first started. This is only valid if your service is configured to use a load
      * balancer. If your service's tasks take a while to start and respond to Elastic
      * Load Balancing health checks, you can specify a health check grace period of up
-     * to 2,147,483,647 seconds. During that time, the ECS service scheduler ignores
-     * the Elastic Load Balancing health check status. This grace period can prevent
-     * the ECS service scheduler from marking tasks as unhealthy and stopping them
-     * before they have time to come up.</p>
+     * to 2,147,483,647 seconds. During that time, the Amazon ECS service scheduler
+     * ignores the Elastic Load Balancing health check status. This grace period can
+     * prevent the ECS service scheduler from marking tasks as unhealthy and stopping
+     * them before they have time to come up.</p>
      */
     inline bool HealthCheckGracePeriodSecondsHasBeenSet() const { return m_healthCheckGracePeriodSecondsHasBeenSet; }
 
@@ -536,10 +539,10 @@ namespace Model
      * first started. This is only valid if your service is configured to use a load
      * balancer. If your service's tasks take a while to start and respond to Elastic
      * Load Balancing health checks, you can specify a health check grace period of up
-     * to 2,147,483,647 seconds. During that time, the ECS service scheduler ignores
-     * the Elastic Load Balancing health check status. This grace period can prevent
-     * the ECS service scheduler from marking tasks as unhealthy and stopping them
-     * before they have time to come up.</p>
+     * to 2,147,483,647 seconds. During that time, the Amazon ECS service scheduler
+     * ignores the Elastic Load Balancing health check status. This grace period can
+     * prevent the ECS service scheduler from marking tasks as unhealthy and stopping
+     * them before they have time to come up.</p>
      */
     inline void SetHealthCheckGracePeriodSeconds(int value) { m_healthCheckGracePeriodSecondsHasBeenSet = true; m_healthCheckGracePeriodSeconds = value; }
 
@@ -549,10 +552,10 @@ namespace Model
      * first started. This is only valid if your service is configured to use a load
      * balancer. If your service's tasks take a while to start and respond to Elastic
      * Load Balancing health checks, you can specify a health check grace period of up
-     * to 2,147,483,647 seconds. During that time, the ECS service scheduler ignores
-     * the Elastic Load Balancing health check status. This grace period can prevent
-     * the ECS service scheduler from marking tasks as unhealthy and stopping them
-     * before they have time to come up.</p>
+     * to 2,147,483,647 seconds. During that time, the Amazon ECS service scheduler
+     * ignores the Elastic Load Balancing health check status. This grace period can
+     * prevent the ECS service scheduler from marking tasks as unhealthy and stopping
+     * them before they have time to come up.</p>
      */
     inline UpdateServiceRequest& WithHealthCheckGracePeriodSeconds(int value) { SetHealthCheckGracePeriodSeconds(value); return *this;}
 
@@ -570,6 +573,9 @@ namespace Model
     Aws::String m_taskDefinition;
     bool m_taskDefinitionHasBeenSet;
 
+    Aws::Vector<CapacityProviderStrategyItem> m_capacityProviderStrategy;
+    bool m_capacityProviderStrategyHasBeenSet;
+
     DeploymentConfiguration m_deploymentConfiguration;
     bool m_deploymentConfigurationHasBeenSet;
 
